# AnnotatedText {: #pret.ui.metanno.AnnotatedText }

::: pret.ui.metanno.AnnotatedText
    options:
        heading_level: 2
        show_bases: false
        show_source: false
        only_class_level: true
